#ifndef DEFINE_ISLIB_COMMAND_PROGRAM_HPP

#define DEFINE_ISLIB_COMMAND_PROGRAM_HPP

//
// Inclusion of standard header file
//
#include <string>

namespace islib
  {
    //
    // Declaration of function
    //
    std::string get_try_help_message ( std::string const & );
    void print_message ( std::string const & );
    void print_error_message ( std::string const & );
  }

#endif // DEFINE_ISLIB_COMMAND_PROGRAM_HPP

//
// End of file
//
